@@ -1,3 +1,5 @@
+// From Intel DPTF github project ESIF/Products/ESIF_CMP/Sources
+// Fix white spaces from the source.
 /* LzmaDec.c -- LZMA Decoder
 2018-07-04 : Igor Pavlov : Public domain */
 
@@ -8,7 +10,7 @@
 /* #include "CpuArch.h" */
 #include "LzmaDec.h"
 
-//#include "EsifSdl.h"
+// For MyMemCpy function only exclude #include "EsifSdl.h"
 #define MyMemcpy(dst, src, len) memcpy(dst, src, len)
 
 #define kNumTopBits 24
@@ -1123,7 +1125,7 @@ static SRes LzmaDec_AllocateProbs2(CLzmaDec *p, const CLzmaProps *propNew, ISzAl
 
 SRes LzmaDec_AllocateProbs(CLzmaDec *p, const Byte *props, unsigned propsSize, ISzAllocPtr alloc)
 {
-  CLzmaProps propNew;
+  CLzmaProps propNew = { 0 };
   RINOK(LzmaProps_Decode(&propNew, props, propsSize));
   RINOK(LzmaDec_AllocateProbs2(p, &propNew, alloc));
   p->prop = propNew;
@@ -1132,7 +1134,7 @@ SRes LzmaDec_AllocateProbs(CLzmaDec *p, const Byte *props, unsigned propsSize, I
 
 SRes LzmaDec_Allocate(CLzmaDec *p, const Byte *props, unsigned propsSize, ISzAllocPtr alloc)
 {
-  CLzmaProps propNew;
+  CLzmaProps propNew = { 0 };
   SizeT dicBufSize;
   RINOK(LzmaProps_Decode(&propNew, props, propsSize));
   RINOK(LzmaDec_AllocateProbs2(p, &propNew, alloc));
