@@ -62,28 +62,8 @@ int cthd_sysfs_cdev_rapl_dram::update() {
 	if (!found)
 		return THD_ERROR;
 
-	cdev_sysfs.update_path(path_name);
+	cdev_sysfs.update_path(std::move(path_name));
 
 	return cthd_sysfs_cdev_rapl::update();
 }
 
-bool cthd_sysfs_cdev_rapl_dram::calculate_phy_max() {
-	if (dynamic_phy_max_enable) {
-		int curr_max_phy;
-		curr_max_phy = thd_engine->rapl_power_meter.rapl_action_get_power(DRAM);
-		thd_log_info("curr_phy_max = %u \n", curr_max_phy);
-		if (curr_max_phy < rapl_min_default_step)
-			return false;
-		if (phy_max < curr_max_phy) {
-			phy_max = curr_max_phy;
-			set_inc_dec_value(phy_max * (float) rapl_power_dec_percent / 100);
-			min_state = phy_max;
-			max_state = min_state
-					- (float) min_state * rapl_low_limit_percent / 100;
-			thd_log_info("DRAM PHY_MAX %d, step %d, max_state %d\n", phy_max,
-					inc_dec_val, max_state);
-		}
-	}
-
-	return true;
-}
