@@ -29,6 +29,10 @@
 #include "thd_sys_fs.h"
 #include "thd_preference.h"
 #include "thd_cdev.h"
+
+#define __STDC_LIMIT_MACROS
+#include <stdint.h>
+
 #include <time.h>
 #include <vector>
 #include <algorithm>    // std::sort
@@ -58,11 +62,14 @@ typedef struct {
 	int target_state;
 	pid_param_t pid_param;
 	cthd_pid pid;
+	int min_max_valid;
+	int min_state;
+	int max_state;
 } trip_pt_cdev_t;
 
 #define DEFAULT_SENSOR_ID	0xFFFF
 
-static bool trip_cdev_sort(trip_pt_cdev_t cdev1, trip_pt_cdev_t cdev2) {
+static bool trip_cdev_sort(trip_pt_cdev_t &cdev1, trip_pt_cdev_t &cdev2) {
 	return (cdev1.influence > cdev2.influence);
 }
 
@@ -83,6 +90,7 @@ private:
 	cthd_cdev *depend_cdev;
 	int depend_cdev_state;
 	trip_point_cdev_depend_rel_t depend_cdev_state_rel;
+	int crit_trip_count;
 
 	bool check_duplicate(cthd_cdev *cdev, int *index) {
 		for (unsigned int i = 0; i < cdevs.size(); ++i) {
@@ -96,6 +104,8 @@ private:
 
 public:
 	static const int default_influence = 0;
+	static const int consecutive_critical_events = 4;
+
 	cthd_trip_point(int _index, trip_point_type_t _type, unsigned int _temp,
 			unsigned int _hyst, int _zone_id, int _sensor_id,
 			trip_control_type_t _control_type = PARALLEL);
@@ -105,9 +115,14 @@ public:
 	void thd_trip_point_add_cdev(cthd_cdev &cdev, int influence,
 			int sampling_period = 0, int target_state_valid = 0,
 			int target_state =
-			TRIP_PT_INVALID_TARGET_STATE, pid_param_t *pid_param = NULL);
+			TRIP_PT_INVALID_TARGET_STATE, pid_param_t *pid_param = NULL,
+			int min_max_valid = 0, int min_state = 0, int max_state = 0);
 
-	void thd_trip_cdev_state_reset();
+	void delete_cdevs() {
+		cdevs.clear();
+	}
+
+	void thd_trip_cdev_state_reset(int force = 0);
 	int thd_trip_point_value() {
 		return temp;
 	}
@@ -143,6 +158,50 @@ public:
 		return cdevs.size();
 	}
 
+
+	int is_target_valid(int &target_state) {
+		target_state = 0;
+		for (unsigned int i = 0; i < cdevs.size(); ++i) {
+			trip_pt_cdev_t &cdev = cdevs[i];
+
+			if (cdev.target_state_valid) {
+				thd_log_debug("matched %d\n", cdev.target_state);
+				target_state = cdev.target_state;
+				return THD_SUCCESS;
+			}
+		}
+
+		return THD_ERROR;
+	}
+
+	int set_first_target_invalid() {
+		if (cdevs.size()) {
+			trip_pt_cdev_t &cdev = cdevs[0];
+			cdev.target_state_valid = 0;
+			return THD_SUCCESS;
+		}
+
+		return THD_ERROR;
+	}
+
+	int set_first_target(int state) {
+		if (cdevs.size()) {
+			trip_pt_cdev_t &cdev = cdevs[0];
+			cdev.target_state_valid = 1;
+			cdev.target_state = state;
+			return THD_SUCCESS;
+		}
+
+		return THD_ERROR;
+	}
+
+	cthd_cdev* get_first_cdev() {
+		if (!cdevs.size())
+			return NULL;
+
+		return cdevs[0].cdev;
+	}
+
 	void set_dependency(std::string cdev, std::string state_str);
 
 #ifndef ANDROID
@@ -154,7 +213,7 @@ public:
 	}
 #endif
 
-	void trip_cdev_add(trip_pt_cdev_t trip_cdev) {
+	void trip_cdev_add(trip_pt_cdev_t &trip_cdev) {
 		int index;
 		if (check_duplicate(trip_cdev.cdev, &index)) {
 			cdevs[index].influence = trip_cdev.influence;
@@ -199,18 +258,21 @@ public:
 			else
 				thd_log_info("\t target_state:not defined\n");
 
+			thd_log_info("min_max %d\n", cdevs[i].min_max_valid);
+
 			if (cdevs[i].pid_param.valid)
 				thd_log_info("\t pid: kp=%g ki=%g kd=%g\n",
 						cdevs[i].pid_param.kp, cdevs[i].pid_param.ki,
 						cdevs[i].pid_param.kd);
+			if (cdevs[i].min_max_valid) {
+				thd_log_info("\t min_state:%d\n", cdevs[i].min_state);
+				thd_log_info("\t max_state:%d\n", cdevs[i].max_state);
+			}
 		}
 	}
 };
 
 static inline bool trip_sort(cthd_trip_point trip1, cthd_trip_point trip2) {
-	if (trip1.get_trip_type() != trip2.get_trip_type())
-		return false;
-
 	return (trip1.get_trip_temp() < trip2.get_trip_temp());
 }
 #endif
